============================
OpenWorkflow
============================
.. image:: https://img.shields.io/pypi/v/gabrieltool.svg
        :target: https://pypi.python.org/pypi/gabrieltool
.. image:: https://github.com/cmusatyalab/openworkflow/workflows/gabrieltool-build/badge.svg
        :target: https://github.com/cmusatyalab/OpenWorkflow/actions
.. image:: https://readthedocs.org/projects/openworkflow/badge/?version=latest
        :target: https://openworkflow.readthedocs.io/en/latest/
        :alt: Documentation Status

A suite of tools for creating wearable cognitive assistants.

* Documentation: https://openworkflow.readthedocs.io.
* Free software: Apache Software License 2.0

What's in here?
----------------------

* `gabrieltool.statemachine`_: A Python library to create and persist wearable cognitive assistants, modeled as a finite state machine. 
* `Examples`_: Examples showing the usage of gabrieltool.statemachine Python package.
* `State Machine Web Editor`_: A browser-based GUI to view and modify state machines. Give it a try at https://cmusatyalab.github.io/OpenWorkflow/

Credits
-------

This research was supported by the National Science Foundation (NSF) under grant
number CNS-1518865. Additional support was provided by Intel, Vodafone, Deutsche
Telekom, Verizon, Crown Castle, Seagate, VMware, MobiledgeX, InterDigital, and
the Conklin Kistler family fund.

This repo was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`gabrieltool.statemachine`: gabrieltool/statemachine
.. _`Examples`: examples
.. _`State Machine Web Editor`: gabrieltool/statemachine-editor-react

